Multi-part interview for creating one of 4 retainers (Legal, Spanish Legal, FAST, or BHA) and allowing for Citizen/Non-Citizen as well as for Custodian signature on behalf of the client for FAST and BHA retainers.